Exception: Google::Cloud::InternalError
- Defined in:
- lib/google/cloud/errors.rb
Overview
Internal errors. Means some invariants expected by underlying system has been broken. If you see one of these errors, something is very broken.
Method Summary
Methods inherited from Error
#body, #code, #details, #domain, #error_info, #error_metadata, #header, #initialize, #metadata, #reason, #status_code, #status_details
Constructor Details
This class inherits a constructor from Google::Cloud::Error